@@ -13,7 +13,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
-# Copyright (C) 2016-2020 Dominik Kriegner <dominik.kriegner@gmail.com>
+# Copyright (C) 2012-2021 Dominik Kriegner <dominik.kriegner@gmail.com>
 """
 simulation subpackage of xrayutilities.
 
@@ -29,7 +29,7 @@ from .darwin_theory import (DarwinModel, DarwinModelAlGaAs001,
                             DarwinModelAlloy, DarwinModelGaInAs001,
                             DarwinModelSiGe001, GradedBuffer)
 from .fit import FitModel
-from .helpers import coplanar_alphai, get_qz
+from .helpers import coplanar_alphaf, coplanar_alphai, get_qz
 from .models import (DiffuseReflectivityModel, DynamicalModel,
                      DynamicalReflectivityModel, KinematicalModel,
                      KinematicalMultiBeamModel, LayerModel, Model,
